==> aws-java-sdk-opsworkscm-1.11.65-sources.jar: com/amazonaws/services/opsworkscm/model/transform/UpdateServerEngineAttributesRequestMarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */
package com.amazonaws.services.opsworkscm.model.transform;

import java.io.ByteArrayInputStream;
import java.util.Collections;
import java.util.Map;
import java.util.List;
import java.util.regex.Pattern;

import com.amazonaws.SdkClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.opsworkscm.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.protocol.json.*;

/**
 * UpdateServerEngineAttributesRequest Marshaller
 */
public class UpdateServerEngineAttributesRequestMarshaller implements
        Marshaller<Request<UpdateServerEngineAttributesRequest>, UpdateServerEngineAttributesRequest> {

    private final SdkJsonProtocolFactory protocolFactory;

    public UpdateServerEngineAttributesRequestMarshaller(SdkJsonProtocolFactory protocolFactory) {
        this.protocolFactory = protocolFactory;
    }

    public Request<UpdateServerEngineAttributesRequest> marshall(UpdateServerEngineAttributesRequest updateServerEngineAttributesRequest) {

        if (updateServerEngineAttributesRequest == null) {
            throw new SdkClientException("Invalid argument passed to marshall(...)");
        }

        Request<UpdateServerEngineAttributesRequest> request = new DefaultRequest<UpdateServerEngineAttributesRequest>(updateServerEngineAttributesRequest,
                "AWSOpsWorksCM");
        request.addHeader("X-Amz-Target", "OpsWorksCM_V2016_11_01.UpdateServerEngineAttributes");

        request.setHttpMethod(HttpMethodName.POST);

        request.setResourcePath("");

        try {
            final StructuredJsonGenerator jsonGenerator = protocolFactory.createGenerator();

            jsonGenerator.writeStartObject();

            if (updateServerEngineAttributesRequest.getServerName() != null) {
                jsonGenerator.writeFieldName("ServerName").writeValue(updateServerEngineAttributesRequest.getServerName());
            }
            if (updateServerEngineAttributesRequest.getAttributeName() != null) {
                jsonGenerator.writeFieldName("AttributeName").writeValue(updateServerEngineAttributesRequest.getAttributeName());
            }
            if (updateServerEngineAttributesRequest.getAttributeValue() != null) {
                jsonGenerator.writeFieldName("AttributeValue").writeValue(updateServerEngineAttributesRequest.getAttributeValue());
            }

            jsonGenerator.writeEndObject();

            byte[] content = jsonGenerator.getBytes();
            request.setContent(new ByteArrayInputStream(content));
            request.addHeader("Content-Length", Integer.toString(content.length));
            request.addHeader("Content-Type", protocolFactory.getContentType());
        } catch (Throwable t) {
            throw new SdkClientException("Unable to marshall request to JSON: " + t.getMessage(), t);
        }

        return request;
    }

}

==> aws-java-sdk-opsworkscm-1.11.75-sources.jar: com/amazonaws/services/opsworkscm/model/transform/UpdateServerEngineAttributesRequestMarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */
package com.amazonaws.services.opsworkscm.model.transform;

import java.io.ByteArrayInputStream;
import java.util.Collections;
import java.util.Map;
import java.util.List;
import java.util.regex.Pattern;

import com.amazonaws.SdkClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.opsworkscm.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.protocol.json.*;

/**
 * UpdateServerEngineAttributesRequest Marshaller
 */
public class UpdateServerEngineAttributesRequestMarshaller implements
        Marshaller<Request<UpdateServerEngineAttributesRequest>, UpdateServerEngineAttributesRequest> {

    private final SdkJsonMarshallerFactory protocolFactory;

    public UpdateServerEngineAttributesRequestMarshaller(SdkJsonMarshallerFactory protocolFactory) {
        this.protocolFactory = protocolFactory;
    }

    public Request<UpdateServerEngineAttributesRequest> marshall(UpdateServerEngineAttributesRequest updateServerEngineAttributesRequest) {

        if (updateServerEngineAttributesRequest == null) {
            throw new SdkClientException("Invalid argument passed to marshall(...)");
        }

        Request<UpdateServerEngineAttributesRequest> request = new DefaultRequest<UpdateServerEngineAttributesRequest>(updateServerEngineAttributesRequest,
                "AWSOpsWorksCM");
        request.addHeader("X-Amz-Target", "OpsWorksCM_V2016_11_01.UpdateServerEngineAttributes");

        request.setHttpMethod(HttpMethodName.POST);

        request.setResourcePath("");

        try {
            final StructuredJsonGenerator jsonGenerator = protocolFactory.createGenerator();

            jsonGenerator.writeStartObject();

            if (updateServerEngineAttributesRequest.getServerName() != null) {
                jsonGenerator.writeFieldName("ServerName").writeValue(updateServerEngineAttributesRequest.getServerName());
            }
            if (updateServerEngineAttributesRequest.getAttributeName() != null) {
                jsonGenerator.writeFieldName("AttributeName").writeValue(updateServerEngineAttributesRequest.getAttributeName());
            }
            if (updateServerEngineAttributesRequest.getAttributeValue() != null) {
                jsonGenerator.writeFieldName("AttributeValue").writeValue(updateServerEngineAttributesRequest.getAttributeValue());
            }

            jsonGenerator.writeEndObject();

            byte[] content = jsonGenerator.getBytes();
            request.setContent(new ByteArrayInputStream(content));
            request.addHeader("Content-Length", Integer.toString(content.length));
            request.addHeader("Content-Type", protocolFactory.getContentType());
        } catch (Throwable t) {
            throw new SdkClientException("Unable to marshall request to JSON: " + t.getMessage(), t);
        }

        return request;
    }

}
